@@ -561,3 +561,24 @@ minuslog_likelihood <- function(param, time, event, b, db,
   -sum(inner_sum + (1 - event_logical) * log(1 - sum_Fks))
 }
 
+
+
+
+
+uniroot.all <- function (f, interval, lower = min(interval), upper = max(interval),
+                         tol = .Machine$double.eps^0.2, maxiter = 1000, n = 100, ...)
+{
+  if (!missing(interval) && length(interval) != 2)
+    stop("'interval' must be a vector of length 2")
+  if (!is.numeric(lower) || !is.numeric(upper) || lower >=
+      upper)
+    stop("lower < upper  is not fulfilled")
+  xseq <- seq(lower, upper, len = n + 1)
+  mod <- f(xseq, ...)
+  Equi <- xseq[which(mod == 0)]
+  ss <- mod[1:n] * mod[2:(n + 1)]
+  ii <- which(ss < 0)
+  for (i in ii) Equi <- c(Equi, uniroot(f, lower = xseq[i],
+                                        upper = xseq[i + 1], ...)$root)
+  return(Equi)
+}
